@@ -44,7 +44,7 @@ if ($debug) {
 }
 
 $classpath_old = $ENV{CLASSPATH};
-$classpath = "$plugin_dir:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.5.0.v20090525.jar:$plugins_dir/org.eclipse.equinox.common_3.5.0.v20090520-1800.jar:$plugins_dir/org.eclipse.core.filesystem_1.2.0.v20090507.jar:$plugins_dir/com.ibm.icu.base_4.0.1.v20090415.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/upcparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar";
+$classpath = "$plugin_dir:$plugins_dir/cdtminer.jar:$plugins_dir/cdtmodel.jar:$plugins_dir/cdtparser.jar:$plugins_dir/org.eclipse.core.runtime_3.6.0.v20100412.jar:$plugins_dir/org.eclipse.equinox.common_3.6.0.v20100315.jar:$plugins_dir/org.eclipse.core.filesystem_1.3.0.v20100419.jar:$plugins_dir/com.ibm.icu.base_4.2.1.v20100412.jar:$plugins_dir/stubs.jar:$plugins_dir/lrparser.jar:$plugins_dir/upcparser.jar:$plugins_dir/xlcparser.jar:$plugins_dir/net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar";
 $classpath .= ":$plugin_dir/dstore_extra_server.jar";
 $classpath .= ":$plugin_dir/dstore_core.jar";
 $classpath .= ":$plugin_dir/dstore_miners.jar";
